@@ -9,7 +9,7 @@ class Sprite:
         self.width = width
         self.height = height
 
-        self.image = pygame.image.load(self.picture)
+        self.image = pygame.image.load(self.picture).convert()
         self.rect = pygame.Rect(0, 0, 0, 0)
 
         if width != None and height != None:
